@@ -1,11 +1,11 @@
 from __future__ import division, absolute_import, unicode_literals
-
-__all__ = ('decorator', 'memoize', 'interruptable')
-
 import errno
 import functools
 
 
+__all__ = ('decorator', 'memoize', 'interruptable')
+
+
 def decorator(caller, func=None):
     """
     Create a new decorator
@@ -46,8 +46,8 @@ def memoize(func):
 
 def _memoize(func, *args, **opts):
     """Implements memoized cache lookups"""
-    if opts: # frozenset is used to ensure hashability
-        key = args, frozenset(opts.items())
+    if opts:  # frozenset is used to ensure hashability
+        key = (args, frozenset(list(opts.items())))
     else:
         key = args
     cache = func.cache  # attribute added by memoize
