@@ -1,6 +1,9 @@
 """Text wrapping and filling.
 """
 from __future__ import division, absolute_import, unicode_literals
+import re
+
+from .compat import ustr
 
 # Copyright (C) 1999-2001 Gregory P. Ward.
 # Copyright (C) 2002, 2003 Python Software Foundation.
@@ -8,10 +11,6 @@ from __future__ import division, absolute_import, unicode_literals
 # Written by Greg Ward <gward@python.net>
 # Simplified for git-cola by David Aguilar <davvid@gmail.com>
 
-import re
-
-from cola.compat import ustr
-
 
 class TextWrapper(object):
     """
@@ -26,7 +25,7 @@ class TextWrapper(object):
         The preferred width of wrapped lines.
       tabwidth (default: 8)
         The width of a tab used when calculating line length.
-      break_on_hyphens (default: true)
+      break_on_hyphens (default: false)
         Allow breaking hyphenated words. If true, wrapping will occur
         preferably on whitespaces and right after hyphens part of
         compound words.
@@ -54,7 +53,7 @@ class TextWrapper(object):
     def __init__(self,
                  width=70,
                  tabwidth=8,
-                 break_on_hyphens=True,
+                 break_on_hyphens=False,
                  drop_whitespace=True):
         self.width = width
         self.tabwidth = tabwidth
@@ -127,9 +126,10 @@ class TextWrapper(object):
 
             # First chunk on line is a space -- drop it, unless this
             # is the very beginning of the text (ie. no lines started yet).
-            if self.drop_whitespace and chunks[-1] == ' ' and lines:
+            if self.drop_whitespace and is_blank(chunks[-1]) and lines:
                 chunks.pop()
 
+            linebreak = False
             while chunks:
                 l = self.chunklen(chunks[-1])
 
@@ -139,6 +139,7 @@ class TextWrapper(object):
                     cur_len += l
                 # Nope, this line is full.
                 else:
+                    linebreak = True
                     break
 
             # The current line is full, and the next chunk is too big to
@@ -147,15 +148,15 @@ class TextWrapper(object):
                 if not cur_line:
                     cur_line.append(chunks.pop())
 
-            # If the last chunk on this line is all a space, drop it.
-            if self.drop_whitespace and cur_line and cur_line[-1] == ' ':
-                cur_line.pop()
-
-            # Avoid whitespace at the beginining of the line.
-            if (self.drop_whitespace and cur_line and
-                    cur_line[0] in (' ', '  ')):
+            # Avoid whitespace at the beginining of split lines
+            if (linebreak and self.drop_whitespace and
+                    cur_line and is_blank(cur_line[0])):
                 cur_line.pop(0)
 
+            # If the last chunk on this line is all a space, drop it.
+            if self.drop_whitespace and cur_line and is_blank(cur_line[-1]):
+                cur_line.pop()
+
             # Convert current line back to a string and store it in list
             # of all lines (return value).
             if cur_line:
@@ -173,7 +174,6 @@ class TextWrapper(object):
         """
         return len(word.replace('\t', '')) + word.count('\t') * self.tabwidth
 
-
     # -- Public interface ----------------------------------------------
 
     def wrap(self, text):
@@ -198,7 +198,7 @@ class TextWrapper(object):
         return "\n".join(self.wrap(text))
 
 
-def word_wrap(text, tabwidth, limit):
+def word_wrap(text, tabwidth, limit, break_on_hyphens=False):
     """Wrap long lines to the specified limit"""
 
     lines = []
@@ -250,7 +250,7 @@ def word_wrap(text, tabwidth, limit):
 
     w = TextWrapper(width=limit,
                     tabwidth=tabwidth,
-                    break_on_hyphens=True,
+                    break_on_hyphens=break_on_hyphens,
                     drop_whitespace=True)
 
     for line in text.split('\n'):
@@ -260,3 +260,7 @@ def word_wrap(text, tabwidth, limit):
             lines.append(w.fill(line))
 
     return '\n'.join(lines)
+
+
+def is_blank(string):
+    return string and not string.strip(' ')
