@@ -10,6 +10,7 @@ from qtpy.QtCore import Signal
 from ..git import git
 from ..git import STDOUT
 from ..i18n import N_
+from ..interaction import Interaction
 from .. import cmds
 from .. import core
 from .. import icons
@@ -113,11 +114,9 @@ class Archive(Dialog):
 
         self.browse = qtutils.create_toolbutton(icon=icons.file_zip())
 
-        self.format_strings = (
-                git.archive('--list')[STDOUT].rstrip().splitlines())
-        self.format_combo = QtWidgets.QComboBox()
-        self.format_combo.setEditable(False)
-        self.format_combo.addItems(self.format_strings)
+        stdout = git.archive('--list')[STDOUT]
+        self.format_strings = stdout.rstrip().splitlines()
+        self.format_combo = qtutils.combo(self.format_strings)
 
         self.close_button = qtutils.close_button()
         self.save_button = qtutils.create_button(text=N_('Save'),
@@ -176,8 +175,8 @@ class Archive(Dialog):
 
     def archive_saved(self):
         cmds.do(cmds.Archive, self.ref, self.fmt, self.prefix, self.filename)
-        qtutils.information(N_('File Saved'),
-                            N_('File saved to "%s"') % self.filename)
+        Interaction.information(
+            N_('File Saved'), N_('File saved to "%s"') % self.filename)
 
     def save_archive(self):
         filename = self.filename
@@ -188,8 +187,9 @@ class Archive(Dialog):
             msg = N_('The file "%s" exists and will be overwritten.') % filename
             info_txt = N_('Overwrite "%s"?') % filename
             ok_txt = N_('Overwrite')
-            if not qtutils.confirm(title, msg, info_txt, ok_txt,
-                                   default=False, icon=icons.save()):
+            if not Interaction.confirm(
+                    title, msg, info_txt, ok_txt,
+                    default=False, icon=icons.save()):
                 return
         self.accept()
 
