@@ -54,7 +54,7 @@ def run_command(title, command):
 
 
 class GitCommandWidget(standard.Dialog):
-    """Nice TextView that reads the output of a command synchronously"""
+    """Text viewer that reads the output of a command synchronously"""
 
     # Keep us in scope otherwise PyQt kills the widget
     def __init__(self, title, parent=None):
@@ -96,7 +96,7 @@ class GitCommandWidget(standard.Dialog):
         self.proc.finished.connect(self.proc_finished)
         self.proc.stateChanged.connect(self.proc_state_changed)
 
-        qtutils.connect_button(self.button_abort, self.abortProc)
+        qtutils.connect_button(self.button_abort, self.abort)
         qtutils.connect_button(self.button_close, self.close)
 
         self._layout = qtutils.vbox(defs.margin, defs.spacing,
@@ -133,12 +133,12 @@ class GitCommandWidget(standard.Dialog):
         cursor.movePosition(cursor.End)
         self.output_text.setTextCursor(cursor)
 
-    def abortProc(self):
+    def abort(self):
         if self.proc.state() != QtCore.QProcess.NotRunning:
             # Terminate seems to do nothing in windows
             self.proc.terminate()
             # Kill the process.
-            QtCore.QTimer.singleShot(1000, self.proc)
+            QtCore.QTimer.singleShot(1000, self.proc.kill)
 
     def closeEvent(self, event):
         if self.proc.state() != QtCore.QProcess.NotRunning:
@@ -148,9 +148,9 @@ class GitCommandWidget(standard.Dialog):
                      'Terminating it could result in data loss.')
             info_text = N_('Abort the action?')
             ok_text = N_('Abort Action')
-            if qtutils.confirm(title, msg, info_text, ok_text,
-                               default=False, icon=icons.close()):
-                self.abortProc()
+            if Interaction.confirm(title, msg, info_text, ok_text,
+                                   default=False, icon=icons.close()):
+                self.abort()
                 event.accept()
             else:
                 event.ignore()
@@ -176,7 +176,7 @@ class ActionDialog(standard.Dialog):
 
     def __init__(self, parent, name, opts):
         standard.Dialog.__init__(self, parent)
-        self.name = name
+        self.action_name = name
         self.opts = opts
 
         try:
@@ -263,7 +263,7 @@ class ActionDialog(standard.Dialog):
 
     def _argstxt_changed(self, value):
         """Store the argstxt value so that we can remember it between calls"""
-        self.VALUES[self.name]['argstxt'] = value
+        self.VALUES[self.action_name]['argstxt'] = value
 
 
 class RevisionSelector(QtWidgets.QWidget):
@@ -274,8 +274,8 @@ class RevisionSelector(QtWidgets.QWidget):
         self._revs = revs
         self._revdict = dict(revs)
 
-        self._rev_label = QtWidgets.QLabel()
-        self._revision = completion.GitRefLineEdit()
+        self._rev_label = QtWidgets.QLabel(self)
+        self._revision = completion.GitRefLineEdit(parent=self)
 
         # Create the radio buttons
         radio_btns = []
