@@ -6,20 +6,20 @@ from qtpy import QtCore
 from qtpy import QtWidgets
 from qtpy.QtCore import Qt
 
-from .. import core
-from .. import gitcmds
-from .. import icons
-from .. import utils
-from .. import qtutils
 from ..i18n import N_
 from ..interaction import Interaction
 from ..git import git
 from ..git import STDOUT
 from ..qtutils import connect_button
 from ..qtutils import create_toolbutton
+from .. import core
+from .. import gitcmds
+from .. import icons
+from .. import utils
+from .. import qtutils
+from . import diff
 from . import defs
 from . import standard
-from .diff import DiffTextEdit
 
 
 def mkdate(timespec):
@@ -59,11 +59,7 @@ class SearchWidget(standard.Dialog):
         icon = icons.search()
         self.search_button = qtutils.create_button(text=N_('Search'),
                                                    icon=icon, default=True)
-        self.max_count = QtWidgets.QSpinBox()
-        self.max_count.setMinimum(5)
-        self.max_count.setMaximum(9995)
-        self.max_count.setSingleStep(5)
-        self.max_count.setValue(500)
+        self.max_count = standard.SpinBox(value=500, mini=5, maxi=9995, step=5)
 
         self.commit_list = QtWidgets.QListWidget()
         self.commit_list.setMinimumSize(QtCore.QSize(1, 1))
@@ -71,7 +67,7 @@ class SearchWidget(standard.Dialog):
         selection_mode = QtWidgets.QAbstractItemView.SingleSelection
         self.commit_list.setSelectionMode(selection_mode)
 
-        self.commit_text = DiffTextEdit(self, whitespace=False)
+        self.commit_text = diff.DiffTextEdit(self, whitespace=False)
 
         self.button_export = qtutils.create_button(text=N_('Export Patches'),
                                                    icon=icons.diff())
@@ -335,8 +331,8 @@ class Search(SearchWidget):
             self.commit_text.setText('')
         else:
             qtutils.set_clipboard(revision)
-            diff = gitcmds.commit_diff(revision)
-            self.commit_text.setText(diff)
+            diff_text = gitcmds.commit_diff(revision)
+            self.commit_text.setText(diff_text)
 
     def export_patch(self):
         revision = self.selected_revision()
